@@ -1,7 +1,4 @@
 package Catalyst::Action::RenderView::ErrorHandler::Action;
-{
-  $Catalyst::Action::RenderView::ErrorHandler::Action::VERSION = '0.100162';
-}
 #ABSTRACT: A Role for any actions that want to react to errors.
 
 use strict;
@@ -9,22 +6,17 @@ use warnings;
 use Moose::Role;
 
 has 'id' => (is => 'ro', isa => 'Str', required => 1);
+has 'ignorePath' => (is => 'ro', isa => 'Str', required => 0);
 
 requires 'perform';
 
 1;
 
+__END__
 
+=head1 DESCRIPTION
 
-=pod
-
-=head1 NAME
-
-Catalyst::Action::RenderView::ErrorHandler::Action - A Role for any actions that want to react to errors.
-
-=head1 VERSION
-
-version 0.100162
+A Role that should be consumed by actions that are implemented
 
 =head1 SYNOPSIS
 
@@ -32,10 +24,6 @@ version 0.100162
 
     with 'Catalyst::Action::RenderView::ErrorHandler::Action';
 
-=head1 DESCRIPTION
-
-A Role that should be consumed by actions that are implemented
-
 =head1 INTERFACE
 
 =head2 ACCESSORS
@@ -60,19 +48,3 @@ email or whatnot
 
 Inherited from L<Moose>
 
-=head1 AUTHOR
-
-Andreas Marienborg <andremar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by Andreas Marienborg.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
-
-__END__
-
