@@ -1,7 +1,4 @@
 package Catalyst::Action::RenderView::ErrorHandler::Action::Log;
-{
-  $Catalyst::Action::RenderView::ErrorHandler::Action::Log::VERSION = '0.100162';
-}
 #ABSTRACT: A logging action for errors.
 
 use strict;
@@ -24,17 +21,12 @@ sub perform {
 
 1;
 
+__END__
 
+=head1 DESCRIPTION
 
-=pod
-
-=head1 NAME
-
-Catalyst::Action::RenderView::ErrorHandler::Action::Log - A logging action for errors.
-
-=head1 VERSION
-
-version 0.100162
+Really a rather useless example of an ErrorHandler action. It uses catalysts
+logging facilities to log errors.
 
 =head1 SYNOPSIS
 
@@ -49,11 +41,6 @@ version 0.100162
                 actions:
                     - log-error
 
-=head1 DESCRIPTION
-
-Really a rather useless example of an ErrorHandler action. It uses catalysts
-logging facilities to log errors.
-
 =head1 INTERFACE
 
 =head2 INHERITED ACCESSORS
@@ -83,19 +70,3 @@ every error.
 
 Inherited from Moose.
 
-=head1 AUTHOR
-
-Andreas Marienborg <andremar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by Andreas Marienborg.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
-
-__END__
-
